Learn R Programming

fields (version 17.3)

LENSExample: Surface temperature sensitivity from the NCAR Climate model.

Description

Based on the NCAR Earth System Model (CESM). the local change in surface temperature (C) expected by a 1 degree change in the global average. This statistic is referred as the climate sensitivity and was found by OLS regression on a 30 member ensemble of climate runs.

Arguments

Format

The usual image format with components x, y and z.

x Equally spaced longitude values.

y Equally spaced latitude values.

z Climate sensitivity on a 288X192 grid.

Examples

Run this code
data(LENSExample)
imagePlot( LENSExample)

# Nathan Lenssen's version
 
divMap(LENSExample$x, LENSExample$y, LENSExample$z,
      worldCol="white", lwd=.5, zCap=2, wrapVal=c(-180, 180))

Run the code above in your browser using DataLab