Learn R Programming

fields (version 17.3)

Krig.null.function: Default function to create fixed matrix part of spatial process model.

Description

Constructs a matrix of terms representing a low order polynomial and binds additional columns due to covariates ( the XMat matrix)

Usage

Krig.null.function(x, XMat = NULL, drop.XMat = FALSE, m)

Value

A matrix where the first columns are the polynomial terms and the following columns are from XMat.

Arguments

x

Spatial locations

XMat

Other covariates to be associated with each location.

drop.XMat

If TRUE only the low order polynomial part is created.

m

The polynomial order is (m-1).

Author

Doug Nychka

Details

This function can be modified to produce a different fixed part of the spatial model. The arguments x, XMat and drop.XMat are required but other arguments can be passed as part of a list in null.args in the call to Krig.

See Also

Krig