Constructs a matrix of terms representing a low order polynomial and binds additional columns due to covariates ( the XMat matrix)
Krig.null.function(x, XMat = NULL, drop.XMat = FALSE, m)A matrix where the first columns are the polynomial terms and the following columns are from XMat.
Spatial locations
Other covariates to be associated with each location.
If TRUE only the low order polynomial part is created.
The polynomial order is (m-1).
Doug Nychka
This function can be modified to produce a different fixed part of the spatial model. The arguments x, XMat and drop.XMat are required but other arguments can be passed as part of a list in null.args in the call to Krig.
Krig